@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.6.2"
+__version__ = "2.6.3"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -31,7 +31,7 @@ class _EvalEnvironment(dict):
         self.parent = parent
 
     def __getitem__(self, item):
-        if item == '_parent_' + self.parent._parent_field_name \
+        if item == '_parent_' + self.parent._parent_name \
                 and self.parent.parent:
             return _EvalEnvironment(self.parent.parent)
         return self.parent._get_eval()[item]
@@ -268,14 +268,18 @@ class One2ManyValueDescriptor(ValueDescriptor):
     def __get__(self, instance, owner):
         value = [('add', [])]
         value_list = getattr(instance, self.name)
+        parent_name = self.definition.get('relation_field', '')
         for record in value_list:
-            if record.id > 0:
-                if record._changed:
-                    value.append(('write', [record.id], record._get_values(
-                        fields=record._changed)))
+            if record.id >= 0:
+                values = record._get_values(fields=record._changed)
+                values.pop(parent_name, None)
+                if record._changed and values:
+                    value.append(('write', [record.id], values))
                 value[0][1].append(record.id)
             else:
-                value.append(('create', record._get_values()))
+                values = record._get_values()
+                values.pop(parent_name, None)
+                value.append(('create', values))
         if value_list.record_removed:
             value.append(('unlink', [x.id for x in value_list.record_removed]))
         if value_list.record_deleted:
@@ -494,8 +498,8 @@ class ModelList(list):
     def pop(self, index=-1):
         self.record_removed.add(self[index])
         self[index]._parent = None
-        self[index]._parent_field_name = None
-        self[index]._parent_name = None
+        self[index]._parent_field_name = ''
+        self[index]._parent_name = ''
         res = super(ModelList, self).pop(index)
         self._changed()
         return res
@@ -504,8 +508,8 @@ class ModelList(list):
     def remove(self, record):
         self.record_deleted.add(record)
         record._parent = None
-        record._parent_field_name = None
-        record._parent_name = None
+        record._parent_field_name = ''
+        record._parent_name = ''
         res = super(ModelList, self).remove(record)
         self._changed()
         return res
